@@ -862,6 +862,102 @@ class TestTkrzw(unittest.TestCase):
     self.assertEqual("E12345F", file.ReadStr(4, 7))
     self.assertEqual(Status.SUCCESS, file.Close())
 
+  # Index tests.
+  def testIndex(self):
+    path = self._make_tmp_path("casket.tkt")
+    index = Index()
+    self.assertEqual(Status.SUCCESS, index.Open(
+      path, True, truncate=True, num_buckets=100))
+    self.assertTrue("Index" in repr(index))
+    self.assertTrue(("path=" + path) in str(index))
+    self.assertFalse(("single", "1") in index)
+    self.assertFalse(("double", "11") in index)
+    self.assertEqual(Status.SUCCESS, index.Add("single", "1"))
+    self.assertEqual(Status.SUCCESS, index.Add("double", "11"))
+    self.assertTrue(("single", "1") in index)
+    self.assertTrue(("double", "11") in index)
+    self.assertEqual(Status.SUCCESS, index.Add("single", "2"))
+    self.assertEqual(Status.SUCCESS, index.Add("double", "22"))
+    self.assertEqual(Status.SUCCESS, index.Add("triple", "222"))
+    values = index.GetValues("single")
+    self.assertEqual(2, len(values))
+    self.assertEqual(b"1", values[0])
+    self.assertEqual(b"2", values[1])
+    values = index.GetValuesStr("triple", 0)
+    self.assertEqual(1, len(values))
+    self.assertEqual("222", values[0])
+    self.assertEqual(0, len(index.GetValuesStr("foo")))
+    self.assertEqual(Status.SUCCESS, index.Remove("single", "1"))
+    self.assertEqual(Status.SUCCESS, index.Remove("double", "11"))
+    self.assertEqual(Status.NOT_FOUND_ERROR, index.Remove("triple", "x"))
+    values = index.GetValuesStr("double")
+    self.assertEqual(1, len(values))
+    self.assertEqual("22", values[0])
+    self.assertEqual(3, index.Count())
+    self.assertEqual(path, index.GetFilePath())
+    self.assertEqual(Status.SUCCESS, index.Synchronize(False))
+    self.assertEqual(Status.SUCCESS, index.Rebuild())
+    self.assertEqual(3, len(index))
+    self.assertEqual(Status.SUCCESS, index.Clear())
+    self.assertEqual(0, index.Count())
+    self.assertTrue(index.IsOpen())
+    self.assertTrue(index.IsWritable())
+    self.assertEqual(Status.SUCCESS, index.Add("first", "1"))
+    self.assertEqual(Status.SUCCESS, index.Add("second", "22"))
+    self.assertEqual(Status.SUCCESS, index.Add("third", "333"))
+    iter = index.MakeIterator()
+    self.assertTrue("IndexIterator" in repr(iter))
+    self.assertTrue("unlocated" in str(iter))
+    iter.First()
+    self.assertTrue("first" in repr(iter))
+    self.assertTrue("first" in str(iter))
+    record = iter.Get()
+    self.assertTrue(record != None)
+    self.assertTrue(b"first", record[0])
+    self.assertTrue(b"1", record[1])
+    iter.Next()
+    record = iter.Get()
+    self.assertTrue(record != None)
+    self.assertTrue(b"second", record[0])
+    self.assertTrue(b"22", record[1])
+    iter.Next()
+    record = iter.Get()
+    self.assertTrue(record != None)
+    self.assertTrue(b"third", record[0])
+    self.assertTrue(b"333", record[1])
+    iter.Next()
+    self.assertEqual(None, iter.Get())
+    iter.Last()
+    record = iter.GetStr()
+    self.assertTrue(record != None)
+    self.assertTrue("third", record[0])
+    self.assertTrue("333", record[1])
+    iter.Previous()
+    record = iter.GetStr()
+    self.assertTrue(record != None)
+    self.assertTrue("second", record[0])
+    self.assertTrue("22", record[1])
+    iter.Previous()
+    record = iter.GetStr()
+    self.assertTrue(record != None)
+    self.assertTrue("first", record[0])
+    self.assertTrue("11", record[1])
+    iter.Previous()
+    self.assertEqual(None, iter.GetStr())
+    iter.Jump("second", "")
+    record = iter.GetStr()
+    self.assertTrue(record != None)
+    self.assertTrue("second", record[0])
+    self.assertTrue("22", record[1])
+    records = {}
+    for key, value in index:
+      records[key.decode()] = value.decode()
+    self.assertEqual(3, len(records))
+    self.assertEqual("1", records["first"])
+    self.assertEqual("22", records["second"])
+    self.assertEqual("333", records["third"])
+    self.assertEqual(Status.SUCCESS, index.Close())
+
 
 # Main routine.
 def main(argv):
